@@ -1,11 +1,11 @@
 /*--------------------------------------------------------------------------
   ----- File:        t1afmtool.c 
-  ----- Author:      Rainer Menzner (rmz@neuroinformatik.ruhr-uni-bochum.de)
-  ----- Date:        2001-02-09
+  ----- Author:      Rainer Menzner (Rainer.Menzner@web.de)
+  ----- Date:        2001-04-01
   ----- Description: This file is part of the t1-library. It contains
                      functions for generating a fallback set of afm data
 		     from type 1 font files.
-  ----- Copyright:   t1lib is copyrighted (c) Rainer Menzner, 1996-1998. 
+  ----- Copyright:   t1lib is copyrighted (c) Rainer Menzner, 1996-2001.
                      As of version 0.5, t1lib is distributed under the
 		     GNU General Public Library Lincense. The
 		     conditions can be found in the files LICENSE and
@@ -331,7 +331,7 @@ int T1_WriteAFMFallbackFile( int FontID)
   afmfilename[i+2]='f';
   afmfilename[i+3]='m';
   
-  if ((afmfile=fopen( afmfilename, "w"))==NULL){
+  if ((afmfile=fopen( afmfilename, "wb"))==NULL){
     sprintf( err_warn_msg_buf,
 	     "Could not open %s, (FontID = %d)",
 	     afmfilename, FontID);
