@@ -774,7 +774,7 @@ void do_fourier(int gno, int setno, int fftflag, int load, int loadx, int invfla
 	      /* carefully get amplitude of complex xform: 
 		 use abs(a[i]) + abs(a[-i]) except for zero term */
 	      if(i) yy[i] = hypot(xx[i], yy[i])+hypot(xx[ilen-i], yy[ilen-i]);
-	      else yy[i]=fabs(xx[i]);
+	      else yy[i]=2*fabs(xx[i]);
 		switch (loadx) {
 		case 0:
 		    xx[i] = i;
