@@ -4,7 +4,7 @@
  * Home page: http://plasma-gate.weizmann.ac.il/Grace/
  * 
  * Copyright (c) 1991-1995 Paul J Turner, Portland, OR
- * Copyright (c) 1996-2001 Grace Development Team
+ * Copyright (c) 1996-2007 Grace Development Team
  * 
  * Maintained by Evgeny Stambulchik
  * 
@@ -785,7 +785,7 @@ reenter:
                     wtmaj = ifscale(swc_start + itmaj*stmajor, scale);
                 } else {
                     wtmaj = swc_start + itmaj*stmajor;
-                    if (t->tl_format == FORMAT_GENERAL && fabs(wtmaj) < 1.0e-6*stmajor) {
+                    if (t->t_round == TRUE && fabs(wtmaj) < 1.0e-6*stmajor) {
                         wtmaj = 0.0;
                     }
                 }
