@@ -6,7 +6,7 @@
  * Copyright (c) 1991-1995 Paul J Turner, Portland, OR
  * Copyright (c) 1996-2001 Grace Development Team
  * 
- * Maintained by Evgeny Stambulchik <fnevgeny@plasma-gate.weizmann.ac.il>
+ * Maintained by Evgeny Stambulchik
  * 
  * 
  *                           All Rights Reserved
@@ -317,6 +317,7 @@ int is_graph_yinvert(int gno);
 int set_graph_xinvert(int gno, int flag);
 int set_graph_yinvert(int gno, int flag);
 
+int is_valid_axis(int gno, int axis);
 int is_axis_active(int gno, int axis);
 int is_zero_axis(int gno, int axis);
 
