@@ -409,7 +409,9 @@ int store_data(ss_data *ssd, int load_type, char *label)
                 nncols++;
             }
         }
-        setcomment(gno, setno, label);
+        if (!strlen(getcomment(gno, setno))) {
+            setcomment(gno, setno, label);
+        }
         
         XCFREE(ssd->data);
         XCFREE(ssd->formats);
