@@ -6,7 +6,7 @@
  * Copyright (c) 1991-1995 Paul J Turner, Portland, OR
  * Copyright (c) 1996-2002 Grace Development Team
  * 
- * Maintained by Evgeny Stambulchik <fnevgeny@plasma-gate.weizmann.ac.il>
+ * Maintained by Evgeny Stambulchik
  * 
  * 
  *                           All Rights Reserved
@@ -380,7 +380,6 @@ void create_autos_frame(void *data)
 					     3,
 					     "Current",
 					     "All",
-					     NULL,
 					     NULL);
 
 	CreateAACDialog(aui.top, rc, define_autos_proc, &aui);
